Welcome to Ext JS 4.1
Description: Create amazing web apps built on web standards. Sencha Touch, HTML5 mobile app framework. Ext JS, cross-browser JavaScript framework. Ext GWT

## Welcome to the Ext JS 4.1!

Ext JS 4.1 is a pure JavaScript application framework that works everywhere from IE6 to the latest Chrome. It enables you to create the best cross-platform applications using nothing but a browser, and has a phenomenal API.

View the Examples Discuss Ext JS 4 on the forum

### What’s New

We have also been posting summaries of new features and changes to our blog:

- Performance enhancement over 4.0
- Grid
- Border Layout
- XTemplate
- Overrides

Learn more on sencha.com

API Docs

Release Notes

### Upgrading

Check out our upgrade guide to see what has changed.

Sencha also offers training courses and professional services for companies wishing to use Ext JS 4.